import os
import sys
from timeit import default_timer as timer
from datetime import datetime, timedelta
import yaml


from mkdocs import utils as mkdocs_utils
from mkdocs.config import config_options, Config
from mkdocs.plugins import BasePlugin


class FlavorWheelPlugin(BasePlugin):
    config_scheme = (
        ('param', config_options.Type(str, default='')),
    )

    def __init__(self):
        self.almafa = []

    def on_serve(self, server, **kwargs):
        return server

    def on_page_markdown(self, markdown, page, config, **kwargs):
        print("on_page_markdown", page.meta)

    def on_page_context(self, context, page, config, nav, **kwargs):
        print("on_page_context", context)


from setuptools import setup, find_packages


setup(
    name='mkdocs-flavorwheel-plugin',
    version='0.0.6',
    description='MkDocs plugin',
    long_description='',
    keywords='mkdocs',
    url='',
    author='Mico Papp',
    author_email='papp.mico@gmail.com',
    license='MIT',
    python_requires='>=3.5',
    install_requires=[
        'mkdocs>=1.0.4'
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    packages=find_packages(),
    entry_points={
        'mkdocs.plugins': [
            'mkdocs-flavorwheel-plugin = mkdocs_flavorwheel_plugin.plugin:FlavorWheelPlugin'
        ]
    }
)
